@@ -59,10 +59,11 @@ Version <= 1.0: All these functions will not be reported.
 
 package Rex::Commands::Box;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 use YAML;
 use Data::Dumper;
@@ -147,7 +148,7 @@ With this function you can create a new Rex/Box. The first parameter of this fun
 
 =cut
 
-sub box(&) { ## no critic ProhibitSubroutinePrototypes
+sub box(&) {
   my $code = shift;
 
   #### too much black magic...
