@@ -31,10 +31,11 @@ With this module you can install packages and files.
 
 package Rex::Commands::Pkg;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 use Rex::Pkg;
 use Rex::Logger;
@@ -240,25 +241,31 @@ This is deprecated since 0.9. Please use L<File> I<file> instead.
 
 =back
 
-This function supports the following hooks:
+This function supports the following L<hooks|Rex::Hook>:
 
-=over 8
+=over 4
 
 =item before
 
-This gets executed before everything is done. The return value of this hook overwrite the original parameters of the function-call.
+This gets executed before anything is done. All original parameters are passed to it.
+
+The return value of this hook overwrites the original parameters of the function-call.
 
 =item before_change
 
-This gets executed right before the new package is installed. This hook is only available for package installations. If you need file hooks, you have to use the file() function.
+This gets executed right before the new package is installed. All original parameters are passed to it.
+
+This hook is only available for package installations. If you need file hooks, you have to use the L<file()|Rex::Commands::File#file> function.
 
 =item after_change
 
-This gets executed right after the new package was installed. This hook is only available for package installations. If you need file hooks, you have to use the file() function.
+This gets executed right after the new package was installed. All original parameters, and the fact of change (C<{ changed => TRUE|FALSE }>) are passed to it.
+
+This hook is only available for package installations. If you need file hooks, you have to use the L<file()|Rex::Commands::File#file> function.
 
 =item after
-
-This gets executed right before the install() function returns.
+ 
+This gets executed right before the C<install()> function returns. All original parameters, and any returned results are passed to it.
 
 =back
 
@@ -595,7 +602,7 @@ sub update_system {
   my @old_installed = $pkg->get_installed;
 
   eval { $pkg->update_system(%option); };
-  Rex::Logger::info( "An error occured for update_system: $@", "warn" ) if $@;
+  Rex::Logger::info( "An error occurred for update_system: $@", "warn" ) if $@;
 
   my @new_installed = $pkg->get_installed;
 
