@@ -24,10 +24,11 @@ With this module you can upload a local file via sftp to a remote host.
 
 package Rex::Commands::Upload;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 require Rex::Exporter;
 use File::Basename qw(basename);
@@ -52,26 +53,27 @@ Perform an upload. If $remote is a directory the file will be uploaded to that d
    upload "localfile", "/path";
  };
 
+This function supports the following L<hooks|Rex::Hook>:
 
-This function supports the following hooks:
-
-=over 8
+=over 4
 
 =item before
 
-This gets executed before everything is done. The return value of this hook overwrite the original parameters of the function-call.
+This gets executed before anything is done. All original parameters are passed to it.
+
+The return value of this hook overwrites the original parameters of the function-call.
 
 =item before_change
 
-This gets executed right before the new file is written.
+This gets executed right before the new file is written. The local file name, and the remote file name are passed as parameters.
 
 =item after_change
 
-This gets executed right after the file was written.
+This gets executed right after the file was written. On top of the local file name, and the remote file name, any returned results are passed as parameters.
 
 =item after
 
-This gets executed right before the upload() function returns.
+This gets executed right before the C<upload()> function returns. All original parameters, and any results returned are passed to it.
 
 =back
 
