@@ -6,10 +6,11 @@
 
 package Rex::Helper::File::Stat::Win32;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 use Fcntl;
 
@@ -67,4 +68,9 @@ sub S_ISSOCK {
   }
 }
 
+sub S_IMODE {
+  shift;
+  Fcntl::S_IMODE(@_);
+}
+
 1;
