@@ -6,13 +6,14 @@
 
 package Rex::Helper::Path;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 use Rex::Helper::File::Spec;
-use File::Basename qw(dirname);
+use File::Basename qw(basename dirname);
 require Exporter;
 
 use base qw(Exporter);
@@ -44,9 +45,22 @@ sub get_file_path {
     $ends_with_slash = 1;
   }
 
+  my $has_wildcard = 0;
+  my $base_name    = basename($file_name);
+
+  if ( $base_name =~ qr{\*} ) {
+    $has_wildcard = 1;
+    $file_name    = dirname($file_name);
+  }
+
   my $fix_path = sub {
     my ($path) = @_;
     $path =~ s:^\./::;
+
+    if ($has_wildcard) {
+      $path = Rex::Helper::File::Spec->catfile( $path, $base_name );
+    }
+
     if ($ends_with_slash) {
       if ( $path !~ m/\/$/ ) {
         return "$path/";
@@ -65,6 +79,10 @@ sub get_file_path {
 
   $::rexfile ||= $0;
 
+  if ( $caller_file =~ m|^/loader/[^/]+/__Rexfile__.pm$| ) {
+    $caller_file = $::rexfile;
+  }
+
   my @path_parts;
   if ( $^O =~ m/^MSWin/ && !Rex::is_ssh() ) {
     @path_parts = split( /\//, $::rexfile );
@@ -197,25 +215,36 @@ sub resolv_path {
 }
 
 sub parse_path {
-  my ($path) = @_;
-  my %hw;
+  my ( $path_with_macro, $replacement_for ) = @_;
 
-  require Rex::Commands::Gather;
+  my $replace_macros = sub {
+    my ( $path, $substitution_for ) = @_;
 
-  $hw{server}      = Rex::Commands::connection()->server;
-  $hw{environment} = Rex::Commands::environment();
+    my $macro = join q(|), keys %{$substitution_for};
 
-  $path =~ s/\{(server|environment)\}/$hw{$1}/gms;
+    ( my $substitution = $path ) =~ s/{($macro)}/$substitution_for->{$1}/gmsx;
 
-  if ( $path =~ m/\{([^\}]+)\}/ ) {
+    return $substitution;
+  };
 
-    # if there are still some variables to replace, we need some information of
-    # the system.
-    %hw = Rex::Commands::Gather::get_system_information();
-    $path =~ s/\{([^\}]+)\}/$hw{$1}/gms;
+  $replacement_for->{server}      //= Rex::Commands::connection()->server;
+  $replacement_for->{environment} //= Rex::Commands::environment();
+
+  my $replacement_path =
+    $replace_macros->( $path_with_macro, $replacement_for );
+
+  if ( $replacement_path =~ m/\{([^\}]+)\}/ ) {
+
+    # if there are still some macros to replace, we need some
+    # information of the system
+
+    require Rex::Commands::Gather;
+    my %hw = Rex::Commands::Gather::get_system_information();
+
+    $replacement_path = $replace_macros->( $replacement_path, \%hw );
   }
 
-  return $path;
+  return $replacement_path;
 }
 
 sub resolve_symlink {
