@@ -6,10 +6,11 @@
 
 package Rex::Interface::File::SSH;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 use Fcntl;
 use Rex::Interface::Fs;
@@ -58,6 +59,10 @@ sub read {
 
 sub write {
   my ( $self, $buf ) = @_;
+
+  utf8::encode($buf)
+    if Rex::Config->get_write_utf8_files && utf8::is_utf8($buf);
+
   $self->{fh}->write($buf);
 }
 
