@@ -6,10 +6,11 @@
 
 package Rex::Interface::Shell::Ash;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 use Rex::Interface::Shell::Bash;
 
@@ -25,15 +26,4 @@ sub new {
   return $self;
 }
 
-sub detect {
-  my ( $self, $con ) = @_;
-
-  my ($shell_path) = $con->_exec("echo \$SHELL");
-  if ( $shell_path =~ m/\/ash$/ ) {
-    return 1;
-  }
-
-  return 0;
-}
-
 1;
