@@ -6,10 +6,11 @@
 
 package Rex::Pkg::Debian;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 use Rex::Helper::Run;
 use Rex::Commands::File;
@@ -25,18 +26,18 @@ sub new {
 
   bless( $self, $proto );
 
+  my $env =
+    'APT_LISTBUGS_FRONTEND=none APT_LISTCHANGES_FRONTEND=none DEBIAN_FRONTEND=noninteractive';
+
   $self->{commands} = {
-    install =>
-      'APT_LISTCHANGES_FRONTEND=none DEBIAN_FRONTEND=noninteractive apt-get -o Dpkg::Options::=--force-confold -y install %s',
+    install => "$env apt-get -o Dpkg::Options::=--force-confold -y install %s",
     install_version =>
-      'APT_LISTCHANGES_FRONTEND=none DEBIAN_FRONTEND=noninteractive apt-get -o Dpkg::Options::=--force-confold -y install %s=%s',
-    update_system =>
-      'APT_LISTCHANGES_FRONTEND=none DEBIAN_FRONTEND=noninteractive apt-get -y -qq upgrade',
-    dist_update_system =>
-      'APT_LISTCHANGES_FRONTEND=none DEBIAN_FRONTEND=noninteractive apt-get -y -qq dist-upgrade',
-    remove            => 'apt-get -y remove %s',
-    purge             => 'dpkg --purge %s',
-    update_package_db => 'apt-get -y update',
+      "$env apt-get -o Dpkg::Options::=--force-confold -y install %s=%s",
+    update_system      => "$env apt-get -y -qq upgrade",
+    dist_update_system => "$env apt-get -y -qq dist-upgrade",
+    remove             => "$env apt-get -y remove %s",
+    purge              => "$env dpkg --purge %s",
+    update_package_db  => "$env apt-get -y update",
   };
 
   return $self;
