@@ -6,12 +6,12 @@
 
 package Rex::Pkg::NetBSD;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
-use Rex::Commands::Run;
 use Rex::Helper::Run;
 use Rex::Commands::File;
 use Rex::Pkg::Base;
