@@ -6,10 +6,11 @@
 
 package Rex::TaskList::Parallel_ForkManager;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.4.1'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 use Data::Dumper;
 use Rex::Logger;
@@ -35,6 +36,8 @@ sub run {
   }
 
   my $fm = Parallel::ForkManager->new( $self->get_thread_count($task) );
+  $fm->set_waitpid_blocking_sleep(
+    Rex::Config->get_waitpid_blocking_sleep_time );
   my $all_servers = $task->server;
 
   $fm->run_on_finish(
