@@ -52,12 +52,13 @@ This is a basic test module to test your code with the help of local VMs. You ca
 
 package Rex::Test::Base;
 
+use 5.010001;
 use strict;
 use warnings;
 
 use base 'Test::Builder::Module';
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 require Rex::Commands;
 use Rex::Commands::Box;
@@ -149,7 +150,7 @@ sub base_vm {
   $self->{vm} = $vm;
 }
 
-sub test(&) { ## no critic ProhibitSubroutinePrototypes
+sub test(&) {
   my $code = shift;
   my $test = __PACKAGE__->new;
   $code->($test);
