@@ -6,10 +6,11 @@
 
 package Rex::Virtualization::Docker::start;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
+our $VERSION = '1.13.3'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -28,7 +29,7 @@ sub execute {
     die("VM $dom not found.");
   }
 
-  i_run "docker start \"$dom\"";
+  i_run "docker start \"$dom\"", fail_ok => 1;
   if ( $? != 0 ) {
     die("Error starting container $dom");
   }
